aboutsummaryrefslogtreecommitdiff
path: root/teukolsky_data.h
diff options
context:
space:
mode:
Diffstat (limited to 'teukolsky_data.h')
-rw-r--r--teukolsky_data.h12
1 files changed, 7 insertions, 5 deletions
diff --git a/teukolsky_data.h b/teukolsky_data.h
index 4967f8f..943407b 100644
--- a/teukolsky_data.h
+++ b/teukolsky_data.h
@@ -41,13 +41,15 @@
*/
enum TDFamily {
/**
* The time-antisymmetric initial data used in Abrahams&Evans PhysRevD v49,n8 (1994).
* Conformally flat spatial metric.
- * r / x x 3 \ / x 2 \
- * K = -60√(2/π) a | --- - (---) | * exp| - (---) | sin(2θ)
- * θ \ L L / \ L /
+ * r / x x 3 \ / x 2 \
+ * K = a | 3 --- - 2 (---) | * exp| - (---) | sin(2θ)
+ * θ \ L L / \ L /
*/
- TD_FAMILY_AE_TIME_ANTISYM = 0,
+ TD_FAMILY_TIME_ANTISYM_CUBIC = 0,
/**
* Simpler time-antisymmetric initial data.
* Conformally flat spatial metric.
@@ -41,13 +41,15 @@
enum TDFamily {
/**
- * The time-antisymmetric initial data used in Abrahams&Evans PhysRevD v49,n8 (1994).
+ * Time-antisymmetric initial data with a cubic radial term multiplied by an
+ * exponential and a quadrupole angular term.
+ * Similar to that used in Abrahams&Evans PhysRevD v49,n8 (1994).
* Conformally flat spatial metric.